@@ -19,6 +19,7 @@
  * 02111-1307, USA.
  */
 
+#include <config.h>
 #include "core.h"
 #include "frame.h"
 #include "workspace.h"
@@ -217,6 +218,22 @@ meta_core_user_raise (Display *xdisplay,
   meta_window_raise (window);
 }
 
+void
+meta_core_user_lower (Display *xdisplay,
+                      Window   frame_xwindow)
+{
+  MetaDisplay *display;
+  MetaWindow *window;
+  
+  display = meta_display_for_x_display (xdisplay);
+  window = meta_display_lookup_x_window (display, frame_xwindow);
+
+  if (window == NULL || window->frame == NULL)
+    meta_bug ("No such frame window 0x%lx!\n", frame_xwindow);
+  
+  meta_window_lower (window);
+}
+
 void
 meta_core_user_focus (Display *xdisplay,
                       Window   frame_xwindow,
@@ -306,6 +323,25 @@ meta_core_maximize (Display *xdisplay,
   meta_window_maximize (window);
 }
 
+void
+meta_core_toggle_maximize (Display *xdisplay,
+                           Window   frame_xwindow)
+{
+  MetaDisplay *display;
+  MetaWindow *window;
+  
+  display = meta_display_for_x_display (xdisplay);
+  window = meta_display_lookup_x_window (display, frame_xwindow);
+
+  if (window == NULL || window->frame == NULL)
+    meta_bug ("No such frame window 0x%lx!\n", frame_xwindow);  
+
+  if (window->maximized)
+    meta_window_unmaximize (window);
+  else
+    meta_window_maximize (window);
+}
+
 void
 meta_core_unmaximize (Display *xdisplay,
                       Window   frame_xwindow)
@@ -418,9 +454,8 @@ meta_core_change_workspace (Display *xdisplay,
     meta_bug ("No such frame window 0x%lx!\n", frame_xwindow);  
 
   meta_window_change_workspace (window,
-                                meta_display_get_workspace_by_screen_index (display,
-                                                                            window->screen,
-                                                                            new_workspace));
+                                meta_screen_get_workspace_by_index (window->screen,
+                                                                    new_workspace));
 }
 
 int
@@ -440,7 +475,7 @@ meta_core_get_active_workspace (Screen *xscreen)
 
   screen = meta_screen_for_x_screen (xscreen);
 
-  return meta_workspace_screen_index (screen->active_workspace);
+  return meta_workspace_index (screen->active_workspace);
 }
 
 int
@@ -606,16 +641,20 @@ meta_core_get_menu_accelerator (MetaMenuOp           menu_op,
     }
 }
 
-char *
+const char*
 meta_core_get_workspace_name_with_index (Display *xdisplay,
-                                         int index)
+                                         Window   xroot,
+                                         int      index)
 {
   MetaDisplay *display;
+  MetaScreen *screen;
   MetaWorkspace *workspace;
 
   display = meta_display_for_x_display (xdisplay);
-  workspace = meta_display_get_workspace_by_index (display, index);
-  return (workspace != NULL) ? workspace->name : NULL;
+  screen = meta_display_screen_for_root (display, xroot);
+  g_assert (screen != NULL);
+  workspace = meta_screen_get_workspace_by_index (screen, index);
+  return workspace ? meta_workspace_get_name (workspace) : NULL;
 }
 
 gboolean
