@@ -131,31 +131,36 @@ activate_cb (GtkWidget *menuitem, gpointer data)
  * The calling code owns the string, and is reponsible to free the
  * memory after use.
  */
-static char *
+static char*
 get_workspace_name_with_accel (Display *display,
                                Window   xroot,
                                int      index)
 {
-  char *name;
-  unsigned int number;
+  const char *name;
+  int number;
 
   name = meta_core_get_workspace_name_with_index (display, xroot, index);
 
+  g_assert (name != NULL);
+  
   /*
    * If the name is of the form "Workspace x" where x is an unsigned
    * integer, insert a '_' before the number if it is less than 10 and
    * return it
    */
-  if (sscanf (name, _("Workspace %u"), &number) == 1)
+  number = 0;
+  if (sscanf (name, _("Workspace %d"), &number) == 1)
     {
+      char *new_name;
+      
       /*
        * Above name is a pointer into the Workspace struct. Here we make
        * a copy copy so we can have our wicked way with it.
        */
-      name = g_strdup_printf (_("Workspace %s%d"),
-                              number < 10 ? "_" : "",
-                              number);
-      return name;
+      new_name = g_strdup_printf (_("Workspace %s%d"),
+                                  number < 10 ? "_" : "",
+                                  number);
+      return new_name;
     }
   else
     {
@@ -164,27 +169,29 @@ get_workspace_name_with_accel (Display *display,
        * add accelerators. Escape any _ characters so that the user's
        * workspace names do not get mangled.
        */
-      char *new_name, *source, *dest;
-      source = name;
+      char *new_name;
+      const char *source;
+      char *dest;
+
       /*
        * Assume the worst case, that every character is a _
        */
-      dest = new_name = g_malloc0 (strlen (name) * 2);
+      new_name = g_malloc0 (strlen (name) * 2 + 1);
+
       /*
        * Now iterate down the strings, adding '_' to escape as we go
        */
+      dest = new_name;
+      source = name;
       while (*source != '\0')
         {
           if (*source == '_')
             *dest++ = '_';
           *dest++ = *source++;
         }
-      /*
-       * We don't free *name as we don't own it, and pass ownership of
-       * *new_name to the calling code.
-       */
+
       return new_name;
-  }
+    }
 }
 
 static GtkWidget*
