@@ -79,6 +79,7 @@ struct _MetaWindow
   char *role;
   char *sm_client_id;
   char *wm_client_machine;
+  char *startup_id;
 
   int net_wm_pid;
   
@@ -321,6 +322,10 @@ void        meta_window_resize_with_gravity (MetaWindow  *window,
                                              int          h,
                                              int          gravity);
 
+
+void        meta_window_fill_horizontal     (MetaWindow  *window);
+void        meta_window_fill_vertical       (MetaWindow  *window);
+
 /* This recalcs the window/frame size, and recalcs the frame
  * size/contents as well.
  */
@@ -406,11 +411,12 @@ void meta_window_get_work_area (MetaWindow    *window,
 gboolean meta_window_same_application (MetaWindow *window,
                                        MetaWindow *other_window);
 
-#define META_WINDOW_IN_NORMAL_TAB_CHAIN(w) \
+#define META_WINDOW_IN_NORMAL_TAB_CHAIN_TYPE(w) \
   ((w)->type != META_WINDOW_DOCK && (w)->type != META_WINDOW_DESKTOP)
-
+#define META_WINDOW_IN_NORMAL_TAB_CHAIN(w) \
+  (((w)->input || (w)->take_focus) && META_WINDOW_IN_NORMAL_TAB_CHAIN_TYPE (w))
 #define META_WINDOW_IN_DOCK_TAB_CHAIN(w) \
-  (! META_WINDOW_IN_NORMAL_TAB_CHAIN (w))
+  (((w)->input || (w)->take_focus) && ! META_WINDOW_IN_NORMAL_TAB_CHAIN_TYPE (w))
 
 void meta_window_refresh_resize_popup (MetaWindow *window);
 
@@ -437,4 +443,6 @@ void meta_window_update_layer (MetaWindow *window);
 gboolean meta_window_get_icon_geometry (MetaWindow    *window,
                                         MetaRectangle *rect);
 
+const char* meta_window_get_startup_id (MetaWindow *window);
+
 #endif
